pilas.actores.utils

Package pilas :: Package actores :: Module utils |
[hide private]
[frames] | no frames]

# Module utils

source code

Functions | [hide private]
ordenar_actores_por_valor_z() Ordena todos los actores para que se impriman con 'z' como criterio de orden. | source code
insertar_como_nuevo_actor(actor) Coloca a un actor en la lista de actores a imprimir en pantalla. | source code
eliminar_a_todos() Elimina a todos los actores de la escena. | source code
destruir_a_todos() Elimina a los actores inmediatamente (evita que exploten o hagan algo). | source code
obtener_actor_en(x, y) Intenta obtener el actor mas cerca de la pantalla (z mas pequeño) en la posición (x, y) | source code
fabricar(clase, cantidad=1, posiciones_al_azar=True, *k, **kv) Genera muchas instancias de una clase particular asignando posiciones aleatorias. | source code

Variables | [hide private]
| __package__ = ``'``pilas.actores``'``

Function Details | [hide private]

### insertar_como_nuevo_actor(actor) | source code
Coloca a un actor en la lista de actores a imprimir en pantalla. :param actor: Actor que se quiere comenzar a mostrar en pantalla.

### obtener_actor_en(x, y) | source code
Intenta obtener el actor mas cerca de la pantalla (z mas pequeño) en la posición (x, y) :param x: Posición horizontal del punto selección. :param y: Posición vertical del punto selección.

### fabricar(clase, cantidad=1, posiciones_al_azar=True, *k, **kv) | source code
Genera muchas instancias de una clase particular asignando posiciones aleatorias.
    >>> pilas.utils.fabricar(pilas.actores.Caja, 30)
:param clase: Clase del objeto a generar. :param cantidad: Cantidad de objetos que se van a crear de esa clase. :param posiciones_al_azar: True o False indicando si se tienen que dar posiciones al azar.